@@ -44,6 +44,7 @@ VOID irc_pr_bs();
 VOID irc_pr_sd();
 VOID irc_pr_ramsch();
 VOID irc_pr_sramsch();
+VOID irc_pr_rskatloser();
 VOID irc_pr_kontra();
 VOID irc_pr_bock();
 VOID irc_pr_resumebock();
@@ -280,6 +281,7 @@ int di_verdoppelt();
 VOID di_buben();
 VOID di_spiel();
 VOID list_fun();
+VOID di_delliste();
 VOID di_liste();
 int ger_toupper();
 VOID pformat();
@@ -294,6 +296,7 @@ VOID di_copyr();
 VOID di_grafik();
 VOID di_strateg();
 VOID di_varianten();
+VOID di_ramschopts();
 VOID di_bockevents();
 VOID di_geschwindigkeit();
 VOID di_irc();
