@@ -73,7 +73,7 @@ enum {
   TX_GEWO_MIT,
   TX_VERL_MIT,
   TX_SPIELLISTE,TX_SPIELLISTE_T,TX_XSKAT,
-  TX_COPYRIGHT,TX_EMAIL,TX_HOMEPAGE,TX_URL,
+  TX_COPYRIGHT,TX_EMAIL,TX_HOMEPAGES,TX_URL1,TX_URL2,
   TX_SORTIEREN,TX_AUFWAERTS,TX_ABWAERTS,TX_ALTERNIEREND,TX_SEQUENTIELL,
   TX_NORMAL,
   TX_GEREIZT_BIS_L,TX_GESPIELT_WIRD,TX_LETZTER_STICH,
@@ -85,6 +85,8 @@ enum {
   TX_OPTIONEN,TX_COMPUTER_T,TX_STRATEGIE,TX_PASSE_K,TX_SAGE18,
   TX_VORSCHLAEGE,TX_VARIANTEN,
   TX_RAMSCH_SPIELEN,TX_IMMER,
+  TX_RAMSCH_VARIANTEN_T,
+  TX_SKAT_GEHT_AN,TX_LETZTEN_STICH,TX_VERLIERER,
   TX_SCHIEBERAMSCH,TX_SKAT_AUFNEHMEN,TX_FERTIG,
   TX_BUBEN_NICHT,
   TX_UNTER_NICHT,
@@ -97,13 +99,15 @@ enum {
   TX_ABKUERZUNG,TX_FRAGEN,TX_NIE,
   TX_BOCK_RUNDEN,TX_UND_RAMSCH,TX_FORTSETZEN,
   TX_BOCK_EREIGNISSE_T,TX_BOCK_EREIGNIS,TX_N_BOCK_EREIGNISSE,
-  TX_BOCK_SPIELE,TX_GRAND_HAND,
+  TX_BOCK_SPIELE,TX_GRAND_HAND,TX_BOCK_SPIEL,
   TX_VERLOREN_MIT_60,TX_GRAND_HAND_GEWONNEN,
   TX_ERFOLGREICHER_KONTRA,TX_KONTRA_RE_ANGESAGT,
   TX_NNN_IN_SPIELLISTE,TX_N00_IN_SPIELLISTE,
   TX_SPIELWERT_72,TX_SPIELWERT_96,
-  TX_EINGABE,TX_TASTATUR,
-  TX_MENU_BUTTON,TX_JEDER,TX_UND_ESC_F1,
+  TX_BENUTZEROBERFLAECHE,TX_TASTATUR,
+  TX_MENU_BUTTON,TX_JEDER,
+  TX_WENIG_HINWEISE,
+  TX_STICH_KARTEN_VON_LINKS_NACH_RECHTS,
   TX_SPITZE,TX_PLUS2,TX_SPITZE_VERLOREN,TX_SPITZE_PROT,
   TX_SPITZE_F1,
   TX_SPITZE_F2,
@@ -120,6 +124,7 @@ enum {
   TX_DEUTSCH,TX_DEUTSCH_4_FARBEN,
   TX_SPRACHE,TX_GERMAN,TX_ENGLISH,
   TX_ALTE_REGELN,
+  TX_INTRO1,TX_INTRO2,
   TX_IRC_T,
   TX_IRC_VERBINDUNG_HERSTELLEN,
   TX_IRC_KONFIGURATION_SIEHE,
