@@ -594,11 +594,11 @@ EXTERN OBJECT diliste[3][66]
 #endif
 ;
 
-EXTERN OBJECT dioptions[3][22]
+EXTERN OBJECT dioptions[3][24]
 #ifdef XDIAL_C
 =
 {{
-  {22,0,0,38,21,OB_NONE,OB_NONE},
+  {24,0,0,38,21,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,36,1,TOB(TX_XSKAT),OB_NONE},
   {OB_EXIT,2,3,34,1,TOB(TX_COPYRIGHT),OB_NONE},
   {OB_NONE,2,5,35,1,TOB(TX_SORTIEREN),OB_NONE},
@@ -619,26 +619,29 @@ EXTERN OBJECT dioptions[3][22]
   {OB_EXIT,5,17,13,1,TOB(TX_SPIELLISTE),OB_NONE},
   {OB_EXIT,20,17,13,1,TOB(TX_OPTIONEN),OB_NONE},
   {OB_EXIT,5,19,13,1,TOB(TX_ENDE),OB_NONE},
-  {OB_EXIT,20,19,13,1,TOB(TX_WEITER),OB_NONE}
+  {OB_EXIT,20,19,13,1,TOB(TX_WEITER),OB_NONE},
+  {OB_HIDDEN,1,14,36,1,TOB(TX_INTRO1),OB_NONE},
+  {OB_HIDDEN,1,15,36,1,TOB(TX_INTRO2),OB_NONE}
 }}
 #endif
 ;
 
-EXTERN OBJECT dicopyr[3][11]
+EXTERN OBJECT dicopyr[3][12]
 #ifdef XDIAL_C
 =
 {{
-  {11,0,0,40,16,OB_NONE,OB_NONE},
+  {12,0,0,40,17,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,38,1,TOB(TX_XSKAT),OB_NONE},
   {OB_CENTERED,1,3,38,1,TOB(TX_COPYRIGHT),OB_NONE},
   {OB_CENTERED,1,4,38,1,TOB(TX_EMAIL),OB_NONE},
-  {OB_CENTERED,1,6,38,1,TOB(TX_HOMEPAGE),OB_NONE},
-  {OB_CENTERED,1,7,38,1,TOB(TX_URL),OB_NONE},
-  {OB_CENTERED,1,9,38,1,TOB(TX_FR1),OB_NONE},
-  {OB_CENTERED,1,10,38,1,TOB(TX_FR2),OB_NONE},
-  {OB_CENTERED,1,11,38,1,TOB(TX_FR3),OB_NONE},
-  {OB_CENTERED,1,12,38,1,TOB(TX_FR4),OB_NONE},
-  {OB_EXIT,13,14,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_CENTERED,1,6,38,1,TOB(TX_HOMEPAGES),OB_NONE},
+  {OB_CENTERED,1,7,38,1,TOB(TX_URL1),OB_NONE},
+  {OB_CENTERED,1,8,38,1,TOB(TX_URL2),OB_NONE},
+  {OB_CENTERED,1,10,38,1,TOB(TX_FR1),OB_NONE},
+  {OB_CENTERED,1,11,38,1,TOB(TX_FR2),OB_NONE},
+  {OB_CENTERED,1,12,38,1,TOB(TX_FR3),OB_NONE},
+  {OB_CENTERED,1,13,38,1,TOB(TX_FR4),OB_NONE},
+  {OB_EXIT,13,15,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
@@ -699,56 +702,67 @@ EXTERN OBJECT distrateg[3][29]
 #endif
 ;
 
-EXTERN OBJECT divarianten[3][37]
+EXTERN OBJECT divarianten[3][31]
 #ifdef XDIAL_C
 =
 {{
-  {37,0,0,42,16,OB_NONE,OB_NONE},
+  {31,0,0,42,14,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,40,1,TOB(TX_VARIANTEN),OB_NONE},
   {OB_NONE,1,3,20,1,TOB(TX_RAMSCH_SPIELEN),OB_NONE},
   {OB_BUTTON,17,3,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,3,7,1,TOB(TX_JA),1},
   {OB_BUTTON,31,3,10,1,TOB(TX_IMMER),-2},
-  {OB_NONE,1,4,20,1,TOB(TX_SCHIEBERAMSCH),OB_NONE},
+  {OB_NONE,1,4,20,1,TOB(TX_KONTRA_SAGEN),OB_NONE},
   {OB_BUTTON,17,4,7,1,TOB(TX_NEIN),1},
-  {OB_BUTTON,24,4,7,1,TOB(TX_JA),-1},
-  {OB_NONE,1,5,20,1,TOB(TX_KONTRA_SAGEN),OB_NONE},
+  {OB_BUTTON,24,4,7,1,TOB(TX_JA),1},
+  {OB_BUTTON,31,4,10,1,TOB(TX_AB18),-2},
+  {OB_NONE,1,5,20,1,TOB(TX_BOCK_RUNDEN),OB_NONE},
   {OB_BUTTON,17,5,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,5,7,1,TOB(TX_JA),1},
-  {OB_BUTTON,31,5,10,1,TOB(TX_AB18),-2},
-  {OB_NONE,1,6,20,1,TOB(TX_BOCK_RUNDEN),OB_NONE},
+  {OB_BUTTON,31,5,10,1,TOB(TX_UND_RAMSCH),-2},
+  {OB_NONE,1,6,18,1,TOB(TX_SPITZE),OB_NONE},
   {OB_BUTTON,17,6,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,6,7,1,TOB(TX_JA),1},
-  {OB_BUTTON,31,6,10,1,TOB(TX_UND_RAMSCH),-2},
-  {OB_NONE,3,7,18,1,TOB(TX_FORTSETZEN),OB_NONE},
+  {OB_BUTTON,31,6,10,1,TOB(TX_PLUS2),-2},
+  {OB_NONE,1,7,18,1,TOB(TX_REVOLUTION),OB_NONE},
   {OB_BUTTON,17,7,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,7,7,1,TOB(TX_JA),-1},
-  {OB_NONE,1,8,18,1,TOB(TX_SPITZE),OB_NONE},
+  {OB_NONE,1,8,18,1,TOB(TX_KLOPFEN),OB_NONE},
   {OB_BUTTON,17,8,7,1,TOB(TX_NEIN),1},
-  {OB_BUTTON,24,8,7,1,TOB(TX_JA),1},
-  {OB_BUTTON,31,8,10,1,TOB(TX_PLUS2),-2},
-  {OB_NONE,1,9,18,1,TOB(TX_REVOLUTION),OB_NONE},
+  {OB_BUTTON,24,8,7,1,TOB(TX_JA),-1},
+  {OB_NONE,1,9,18,1,TOB(TX_SCHENKEN),OB_NONE},
   {OB_BUTTON,17,9,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,9,7,1,TOB(TX_JA),-1},
-  {OB_NONE,1,10,18,1,TOB(TX_KLOPFEN),OB_NONE},
+  {OB_NONE,1,10,18,1,TOB(TX_ALTE_REGELN),OB_NONE},
   {OB_BUTTON,17,10,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,10,7,1,TOB(TX_JA),-1},
-  {OB_NONE,1,11,18,1,TOB(TX_SCHENKEN),OB_NONE},
-  {OB_BUTTON,17,11,7,1,TOB(TX_NEIN),1},
-  {OB_BUTTON,24,11,7,1,TOB(TX_JA),-1},
-  {OB_NONE,1,12,18,1,TOB(TX_ALTE_REGELN),OB_NONE},
-  {OB_BUTTON,17,12,7,1,TOB(TX_NEIN),1},
-  {OB_BUTTON,24,12,7,1,TOB(TX_JA),-1},
-  {OB_EXIT,14,14,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_EXIT,14,12,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
 
-EXTERN OBJECT dibockevents[3][11]
+EXTERN OBJECT diramschopts[3][9]
 #ifdef XDIAL_C
 =
 {{
-  {11,0,0,42,14,OB_NONE,OB_NONE},
+  {9,0,0,42,9,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,40,1,TOB(TX_RAMSCH_VARIANTEN_T),OB_NONE},
+  {OB_NONE,1,3,20,1,TOB(TX_SCHIEBERAMSCH),OB_NONE},
+  {OB_BUTTON,15,3,7,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,22,3,7,1,TOB(TX_JA),-1},
+  {OB_NONE,1,5,20,1,TOB(TX_SKAT_GEHT_AN),OB_NONE},
+  {OB_BUTTON,15,5,15,1,TOB(TX_LETZTEN_STICH),1},
+  {OB_BUTTON,30,5,11,1,TOB(TX_VERLIERER),-1},
+  {OB_EXIT,14,7,14,1,TOB(TX_WEITER),OB_NONE}
+}}
+#endif
+;
+
+EXTERN OBJECT dibockevents[3][14]
+#ifdef XDIAL_C
+=
+{{
+  {14,0,0,42,16,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,40,1,TOB(TX_BOCK_EREIGNISSE_T),OB_NONE},
   {OB_BUTTON,2,3,38,1,TOB(TX_VERLOREN_MIT_60),OB_NONE},
   {OB_BUTTON,2,4,38,1,TOB(TX_GRAND_HAND_GEWONNEN),OB_NONE},
@@ -758,7 +772,10 @@ EXTERN OBJECT dibockevents[3][11]
   {OB_BUTTON,2,8,38,1,TOB(TX_N00_IN_SPIELLISTE),OB_NONE},
   {OB_BUTTON,2,9,38,1,TOB(TX_SPIELWERT_72),OB_NONE},
   {OB_BUTTON,2,10,38,1,TOB(TX_SPIELWERT_96),OB_NONE},
-  {OB_EXIT,14,12,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_NONE,3,12,22,1,TOB(TX_FORTSETZEN),OB_NONE},
+  {OB_BUTTON,26,12,7,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,33,12,7,1,TOB(TX_JA),-1},
+  {OB_EXIT,14,14,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
@@ -804,25 +821,30 @@ EXTERN OBJECT diirc[]
 #endif
 ;
 
-EXTERN OBJECT dieingabe[3][15]
+EXTERN OBJECT digui[3][20]
 #ifdef XDIAL_C
 =
 {{
-  {15,0,0,38,12,OB_NONE,OB_NONE},
-  {OB_CENTERED|OB_UNDERLINED,1,1,36,1,TOB(TX_EINGABE),OB_NONE},
-  {OB_CENTERED,1,3,36,1,TOB(TX_MENU_BUTTON),OB_NONE},
+  {20,0,0,42,17,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,40,1,TOB(TX_BENUTZEROBERFLAECHE),OB_NONE},
+  {OB_CENTERED,1,3,40,1,TOB(TX_MENU_BUTTON),OB_NONE},
   {OB_BUTTON,3,4,7,1,TOB(TX_JEDER),1},
   {OB_BUTTON,11,4,4,1,OB_NONE,1},
   {OB_BUTTON,16,4,4,1,OB_NONE,1},
   {OB_BUTTON,21,4,4,1,OB_NONE,1},
   {OB_BUTTON,26,4,4,1,OB_NONE,1},
   {OB_BUTTON,31,4,4,1,OB_NONE,-5},
-  {OB_CENTERED,1,5,36,1,TOB(TX_UND_ESC_F1),OB_NONE},
-  {OB_CENTERED,1,7,36,1,TOB(TX_TASTATUR),OB_NONE},
-  {OB_BUTTON,3,8,10,1,TOB(TX_NEIN),1},
-  {OB_BUTTON,14,8,10,1,TOB(TX_JA),1},
-  {OB_BUTTON,25,8,10,1,TOB(TX_IMMER),-2},
-  {OB_EXIT,12,10,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_CENTERED,1,6,40,1,TOB(TX_TASTATUR),OB_NONE},
+  {OB_BUTTON,3,7,10,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,14,7,10,1,TOB(TX_JA),1},
+  {OB_BUTTON,25,7,10,1,TOB(TX_IMMER),-2},
+  {OB_CENTERED,1,9,40,1,TOB(TX_WENIG_HINWEISE),OB_NONE},
+  {OB_BUTTON,3,10,10,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,14,10,10,1,TOB(TX_JA),-1},
+  {OB_CENTERED,1,12,40,1,TOB(TX_STICH_KARTEN_VON_LINKS_NACH_RECHTS),OB_NONE},
+  {OB_BUTTON,3,13,10,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,14,13,10,1,TOB(TX_JA),-1},
+  {OB_EXIT,14,15,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
